Layer

Struct Layer 

pub struct Layer { /* private fields */ }
A layer object.

Implementations

Source

impl Layer

pub fn id(&self) -> Token

Returns the ID of self.

pub fn attr(&self, id: Token) -> Option<&Attr>

Finds the first attribute with id.

pub fn payloads(&self) -> Box<dyn Iterator<Item = &Payload>>

Returns an Iterator for the payloads of self.

pub fn add_layer(&mut self, ctx: &mut Context, id: Token) -> &mut Layer

Allocates a new Layer and add it as a child.

pub fn add_attr(&mut self, ctx: &mut Context, id: Token) -> &mut Attr

Allocates a new Attr and add it as a child.

pub fn add_attr_alias(&mut self, ctx: &mut Context, alias: Token, target: Token)

Allocates a new alias Attr.

pub fn add_payload(&mut self, ctx: &mut Context) -> &mut Payload

Allocates a new Payload and add it as a child.

pub fn add_error(&mut self, ctx: &mut Context, id: Token, msg: &str)

Allocates a new error Attr.

pub fn add_tag(&mut self, ctx: &mut Context, id: Token)

Adds id as a tag of self.

pub fn parent(&self) -> Option<&Layer>

Returns a reference to the parent of self.

pub fn parent_mut(&mut self) -> Option<&mut Layer>

Returns a mutable reference to the parent of self.

pub fn range(&self) -> Range

Returns the range of self.

pub fn set_range(&mut self, range: &Range)

Sets the range of self.

pub fn worker(&self) -> u8

Returns the worker ID of self.

pub fn set_worker(&mut self, worker: u8)

Sets the worker ID of self.